@@ -66,20 +66,6 @@ drive_button_class_init (DriveButtonClass *class)
     G_OBJECT_CLASS(class)->dispose = drive_button_dispose;
     GTK_WIDGET_CLASS(class)->button_press_event = drive_button_button_press;
     GTK_WIDGET_CLASS(class)->key_press_event = drive_button_key_press;
-
-    gtk_rc_parse_string ("\n"
-			 "   style \"drive-button-style\"\n"
-			 "   {\n"
-			 "      GtkWidget::focus-line-width=0\n"
-			 "      GtkWidget::focus-padding=0\n"
-			 "      bg_pixmap[NORMAL] = \"<parent>\"\n"
-			 "      bg_pixmap[ACTIVE] = \"<parent>\"\n"
-			 "      bg_pixmap[PRELIGHT] = \"<parent>\"\n"
-			 "      bg_pixmap[INSENSITIVE] = \"<parent>\"\n"
-			 "   }\n"
-			 "\n"
-			 "    class \"DriveButton\" style \"drive-button-style\"\n"
-			 "\n");
 }
 
 static void
@@ -180,7 +166,7 @@ position_menu (GtkMenu *menu, gint *x, gint *y,
 
     direction = gtk_widget_get_direction (widget);
 
-    gtk_widget_get_requisition (GTK_WIDGET (menu), &requisition);
+    gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
     twidth = requisition.width;
     theight = requisition.height;
 
@@ -489,23 +475,22 @@ escape_underscores (const char *str)
     return new_str;
 }
 static GtkWidget *
-create_menu_item (DriveButton *self, const gchar *icon_name,
-		  const gchar *label, GCallback callback,
-		  gboolean sensitive)
+create_menu_item (DriveButton *self,
+                  const gchar *icon_name,
+                  const gchar *label,
+                  GCallback    callback,
+                  gboolean     sensitive)
 {
-    GtkWidget *item, *image;
+    GtkWidget *item;
+
+    item = gtk_menu_item_new_with_mnemonic (label);
 
-    item = gtk_image_menu_item_new_with_mnemonic (label);
-    if (icon_name) {
-	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-	gtk_widget_show (image);
-    }
     if (callback)
-	g_signal_connect_object (item, "activate", callback, self,
-				 G_CONNECT_SWAPPED);
+        g_signal_connect_object (item, "activate", callback, self, G_CONNECT_SWAPPED);
+
     gtk_widget_set_sensitive (item, sensitive);
     gtk_widget_show (item);
+
     return item;
 }
 
@@ -513,6 +498,7 @@ static void
 open_drive (DriveButton *self, GtkWidget *item)
 {
     GdkScreen *screen;
+    GdkDisplay *display;
     GtkWidget *dialog;
     GFile *file = NULL;
     GList *files = NULL;
@@ -537,8 +523,10 @@ open_drive (DriveButton *self, GtkWidget *item)
     app_info = g_desktop_app_info_new ("nautilus.desktop");
 
     if (app_info) {
-	  launch_context = gdk_app_launch_context_new ();
-	  screen = gtk_widget_get_screen (GTK_WIDGET (self));
+        screen = gtk_widget_get_screen (GTK_WIDGET (self));
+        display = gdk_screen_get_display (screen);
+        launch_context = gdk_display_get_app_launch_context (display);
+
 	  gdk_app_launch_context_set_screen (launch_context, screen);
 	  files = g_list_prepend (files, file);
 	  g_app_info_launch (G_APP_INFO (app_info),
@@ -562,8 +550,7 @@ open_drive (DriveButton *self, GtkWidget *item)
 	                                                NULL);
 	  else
 	      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-	                                                _("Could not find Nautilus"),
-	                                                NULL);
+	                                                "%s", _("Could not find Nautilus"));
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (gtk_widget_destroy), NULL);
