@@ -1,15 +1,10 @@
-#!/usr/bin/python
-
-from gi.repository import GObject, Gtk, Gdk, GdkPixbuf, Gio
+from gi.repository import GObject, Gtk, GdkPixbuf
 import os
 import invest
 from gettext import gettext as _
-from invest import *
-import sys
 from os.path import join
-import urllib
+import urllib.request, urllib.parse, urllib.error
 from threading import Thread
-import time
 
 AUTOREFRESH_TIMEOUT = 20*60*1000 # 15 minutes
 
@@ -47,8 +42,9 @@ class ImageRetriever(Thread, _IdleObject):
 		
 	def run(self):
 		self.image = Gtk.Image()
-		try: sock = urllib.urlopen(self.image_url, proxies = invest.PROXY)
-		except Exception, msg:
+		try:
+			sock = urllib.request.urlopen(self.image_url)
+		except Exception as msg:
 			invest.debug("Error while opening %s: %s" % (self.image_url, msg))
 		else:
 			loader = GdkPixbuf.PixbufLoader()
@@ -114,7 +110,7 @@ class FinancialChart:
 		try:
 			pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(join(invest.ART_DATA_DIR, "invest_neutral.svg"), 96,96)
 			self.ui.get_object("plot").set_from_pixbuf(pixbuf)
-		except Exception, msg:
+		except Exception as msg:
 			invest.debug("Could not load 'invest-neutral.svg' file: %s" % msg)
 			pass
 		
