@@ -1,14 +1,14 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 import unittest
-from os.path import *
+from os.path import abspath, dirname
 import sys
 
 # Make sure we run the local version
 sys.path.insert(0, abspath(dirname(__file__) + "/.."))
-print sys.path
+print(sys.path)
 
-import quotes
+from . import quotes
 import invest
 
 def null_function (*args):
