@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Carlos Garnacho Parro  <carlosg@gnome.org>
  */
@@ -44,13 +43,11 @@
 #include "modem-applet.h"
 
 #define MODEM_APPLET_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TYPE_MODEM_APPLET, ModemAppletPrivate))
-#define NETWORK_TOOL "network-admin"
 #define END_OF_REQUEST "<!-- GST: end of request -->\n"
 #define BUF_SIZE 1024
 
 typedef void (*DirectiveCallback) (ModemApplet*, xmlDoc*);
 typedef struct _BackendDirective   BackendDirective;
-typedef struct _ModemAppletPrivate ModemAppletPrivate;
 
 struct _ModemAppletPrivate
 {
@@ -59,7 +56,7 @@ struct _ModemAppletPrivate
   GtkIconTheme   *icon_theme;
   GdkPixbuf      *icon;
   GtkWidget      *image;
-  GtkActionGroup *action_group;
+  GSimpleActionGroup *action_group;
 
   /* auth dialog */
   GtkWidget    *auth_dialog;
@@ -87,6 +84,8 @@ struct _ModemAppletPrivate
   GSList *directives;
   gboolean directive_running;
 
+  gint size;
+
   /* interface data */
   gboolean configured;  /* is configured? */
   gboolean enabled;     /* is enabled? */
@@ -112,23 +111,22 @@ static gboolean update_tooltip      (ModemApplet *applet);
 static gboolean dispatch_directives (ModemApplet *applet);
 static gboolean update_info         (ModemApplet *applet);
 
-static void modem_applet_change_size (PanelApplet *applet, guint size);
+static void modem_applet_size_allocate (GtkWidget     *widget,
+                                        GtkAllocation *allocation,
+                                        gpointer       user_data);
 
-static void modem_applet_change_background (PanelApplet *app,
-					    PanelAppletBackgroundType type,
-					    GdkColor  *colour,
-					    GdkPixmap *pixmap);
-
-static void on_modem_applet_about_clicked (GtkAction   *action,
-					   ModemApplet *applet);
-static void on_modem_applet_activate      (GtkAction   *action,
-					   ModemApplet *applet);
-static void on_modem_applet_deactivate    (GtkAction   *action,
-					   ModemApplet *applet);
-static void on_modem_applet_properties_clicked (GtkAction   *action,
-						ModemApplet *applet);
-static void on_modem_applet_help_clicked  (GtkAction   *action,
-					   ModemApplet *applet);
+static void on_modem_applet_about_clicked (GSimpleAction *action,
+                                           GVariant      *parameter,
+                                           gpointer       user_data);
+static void on_modem_applet_activate      (GSimpleAction *action,
+                                           GVariant      *parameter,
+                                           gpointer       user_data);
+static void on_modem_applet_deactivate    (GSimpleAction *action,
+                                           GVariant      *parameter,
+                                           gpointer       user_data);
+static void on_modem_applet_properties_clicked (GSimpleAction *action,
+                                                GVariant      *parameter,
+                                                gpointer       user_data);
 
 static void launch_backend                (ModemApplet      *applet,
 					   gboolean          root_auth);
@@ -136,43 +134,22 @@ static void shutdown_backend              (ModemApplet *applet,
 					   gboolean     backend_alive,
 					   gboolean     already_waiting);
 
-static gpointer parent_class;
-
-static const GtkActionEntry menu_actions[] = {
-  { "Activate", GTK_STOCK_EXECUTE, N_("_Activate"),
-    NULL, NULL,
-    G_CALLBACK (on_modem_applet_activate) },
-  { "Deactivate", GTK_STOCK_STOP, N_("_Deactivate"),
-    NULL, NULL,
-    G_CALLBACK (on_modem_applet_deactivate) },
-  { "Properties", GTK_STOCK_PROPERTIES, N_("_Properties"),
-    NULL, NULL,
-    G_CALLBACK (on_modem_applet_properties_clicked) },
-  { "Help", GTK_STOCK_HELP, N_("_Help"),
-    NULL, NULL,
-    G_CALLBACK (on_modem_applet_help_clicked) },
-  { "About", GTK_STOCK_ABOUT, N_("_About"),
-    NULL, NULL,
-    G_CALLBACK (on_modem_applet_about_clicked) }
+static const GActionEntry menu_actions [] = {
+  { "activate", on_modem_applet_activate, NULL, NULL, NULL },
+  { "deactivate", on_modem_applet_deactivate, NULL, NULL, NULL },
+  { "preferences", on_modem_applet_properties_clicked, NULL, NULL, NULL },
+  { "about", on_modem_applet_about_clicked, NULL, NULL, NULL }
 };
 
-G_DEFINE_TYPE (ModemApplet, modem_applet, PANEL_TYPE_APPLET)
+G_DEFINE_TYPE_WITH_PRIVATE (ModemApplet, modem_applet, PANEL_TYPE_APPLET)
 
 static void
 modem_applet_class_init (ModemAppletClass *class)
 {
-  GObjectClass     *object_class;
-  PanelAppletClass *applet_class;
+  GObjectClass *object_class;
 
   object_class = G_OBJECT_CLASS (class);
-  applet_class = PANEL_APPLET_CLASS (class);
-  parent_class = g_type_class_peek_parent (class);
-
-  object_class->finalize    = modem_applet_finalize;
-  applet_class->change_size = modem_applet_change_size;
-  applet_class->change_background = modem_applet_change_background;
-
-  g_type_class_add_private (object_class, sizeof (ModemAppletPrivate));
+  object_class->finalize = modem_applet_finalize;
 }
 
 static void
@@ -190,6 +167,7 @@ modem_applet_init (ModemApplet *applet)
   priv->icon = NULL;
   priv->icon_theme = gtk_icon_theme_get_default ();
   priv->image = gtk_image_new ();
+  priv->size = 48;
 
   priv->auth_dialog       = GTK_WIDGET (gtk_builder_get_object (priv->builder, "auth_dialog"));
   priv->auth_dialog_label = GTK_WIDGET (gtk_builder_get_object (priv->builder, "auth_dialog_label"));
@@ -202,7 +180,7 @@ modem_applet_init (ModemApplet *applet)
   g_signal_connect (G_OBJECT (priv->report_window), "delete-event",
 		    G_CALLBACK (gtk_widget_hide), NULL);
 
-  pixbuf = gtk_icon_theme_load_icon (priv->icon_theme, "gnome-modem-monitor-applet", 48, 0, NULL);
+  pixbuf = gtk_icon_theme_load_icon (priv->icon_theme, "gnome-modem-monitor-applet", priv->size, 0, NULL);
   gtk_image_set_from_pixbuf (GTK_IMAGE (priv->report_window_image), pixbuf);
   g_object_unref (pixbuf);
 
@@ -240,62 +218,43 @@ modem_applet_finalize (GObject *object)
       g_free (priv->lock_file);
     }
 
-  if (G_OBJECT_CLASS (parent_class)->finalize)
-    (* G_OBJECT_CLASS (parent_class)->finalize) (object);
+  if (G_OBJECT_CLASS (modem_applet_parent_class)->finalize)
+    G_OBJECT_CLASS (modem_applet_parent_class)->finalize (object);
 }
 
 static void
-modem_applet_change_size (PanelApplet *applet,
-			  guint        size)
+modem_applet_size_allocate (GtkWidget     *widget,
+                            GtkAllocation *allocation,
+                            gpointer       user_data)
 {
+  ModemApplet *applet = MODEM_APPLET (user_data);
   ModemAppletPrivate *priv = MODEM_APPLET_GET_PRIVATE (applet);
+  PanelAppletOrient orient = panel_applet_get_orient (PANEL_APPLET (applet));
+  gint old_size = priv->size;
+
+  if (orient == PANEL_APPLET_ORIENT_UP || orient == PANEL_APPLET_ORIENT_DOWN) {
+    priv->size = allocation->height;
+  } else {
+    priv->size = allocation->width;
+  }
+
+  /* Make icon little smaller than panel size */
+  priv->size -= 4;
+
+  if (old_size == priv->size)
+    return;
 
   if (priv->icon)
     g_object_unref (priv->icon);
 
   /* this might be too much overload, maybe should we get just one icon size and scale? */
   priv->icon = gtk_icon_theme_load_icon (priv->icon_theme,
-					 "gnome-modem", size, 0, NULL);
+					 "gnome-modem", priv->size,
+					 GTK_ICON_LOOKUP_FORCE_SIZE,
+					 NULL);
   gtk_image_set_from_pixbuf (GTK_IMAGE (priv->image), priv->icon);
 }
 
-static void
-modem_applet_change_background (PanelApplet *app,
-				PanelAppletBackgroundType type,
-				GdkColor  *colour,
-				GdkPixmap *pixmap)
-{
-  ModemApplet *applet = MODEM_APPLET (app);
-  GtkRcStyle *rc_style;
-  GtkStyle *style;
-
-  /* reset style */
-  gtk_widget_set_style (GTK_WIDGET (applet), NULL);
-  rc_style = gtk_rc_style_new ();
-  gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-  g_object_unref (rc_style);
-
-  switch (type)
-    {
-    case PANEL_NO_BACKGROUND:
-      break;
-    case PANEL_COLOR_BACKGROUND:
-      gtk_widget_modify_bg (GTK_WIDGET (applet),
-			    GTK_STATE_NORMAL, colour);
-      break;
-    case PANEL_PIXMAP_BACKGROUND:
-      style = gtk_style_copy (GTK_WIDGET (applet)->style);
-
-      if (style->bg_pixmap[GTK_STATE_NORMAL])
-        g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-
-      style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-      gtk_widget_set_style (GTK_WIDGET (applet), style);
-      g_object_unref (style);
-      break;
-    }
-}
-
 static gboolean
 pulse_progressbar (GtkWidget *progressbar)
 {
@@ -629,14 +588,16 @@ shutdown_backend (ModemApplet *applet, gboolean backend_alive, gboolean already_
 static void
 update_popup_buttons (ModemApplet *applet)
 {
-  GtkAction *action;
-  ModemAppletPrivate *priv = MODEM_APPLET_GET_PRIVATE (applet);
+  GSimpleAction *action;
+  ModemAppletPrivate *priv;
 
-  action = gtk_action_group_get_action (priv->action_group, "Activate");
-  gtk_action_set_sensitive (action, priv->configured && !priv->enabled);
+  priv = MODEM_APPLET_GET_PRIVATE (applet);
 
-  action = gtk_action_group_get_action (priv->action_group, "Deactivate");
-  gtk_action_set_sensitive (action, priv->configured && priv->enabled);
+  action = (GSimpleAction *) g_action_map_lookup_action (G_ACTION_MAP (priv->action_group), "activate");
+  g_simple_action_set_enabled (action, priv->configured && !priv->enabled);
+
+  action = (GSimpleAction *) g_action_map_lookup_action (G_ACTION_MAP (priv->action_group), "deactivate");
+  g_simple_action_set_enabled (action, priv->configured && !priv->enabled);
 }
 
 static void
@@ -895,23 +856,32 @@ launch_backend (ModemApplet *applet, gboolean root_auth)
 static gboolean
 launch_config_tool (GdkScreen *screen, gboolean is_isdn)
 {
-  gchar    *argv[4], *application;
-  gboolean  ret;
+  GAppInfo *app_info;
+  GError   *error;
 
-  application = g_find_program_in_path (NETWORK_TOOL);
+  error = NULL;
+  app_info = g_app_info_create_from_commandline ("gnome-control-center network",
+                                                 NULL,
+                                                 G_APP_INFO_CREATE_NONE,
+                                                 &error);
+
+  if (error) {
+    g_warning ("Cannot launch application: %s", error->message);
+
+    g_error_free (error);
+    g_object_unref (app_info);
 
-  if (!application)
     return FALSE;
+  }
 
-  argv[0] = application;
-  argv[1] = "--configure-type";
-  argv[2] = (is_isdn) ? "isdn" : "modem";
-  argv[3] = NULL;
+  if (!g_app_info_launch (app_info, NULL, NULL, &error)) {
+    g_warning ("Cannot launch application: %s", error->message);
+    g_error_free (error);
+  }
 
-  ret = gdk_spawn_on_screen (screen, NULL, argv, NULL, 0,
-			     NULL, NULL, NULL, NULL);
-  g_free (application);
-  return ret;
+  g_object_unref (app_info);
+
+  return TRUE;
 }
 
 static void
@@ -936,9 +906,9 @@ toggle_interface_root (ModemApplet *applet, gboolean enable)
 				   GTK_DIALOG_MODAL,
 				   GTK_MESSAGE_QUESTION,
 				   GTK_BUTTONS_NONE,
-				   text);
+				   "%s", text);
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-			  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			  _("_Cancel"), GTK_RESPONSE_CANCEL,
 			  (enable) ? _("C_onnect") : _("_Disconnect"),
 			  GTK_RESPONSE_OK, NULL);
   gtk_window_set_screen (GTK_WINDOW (dialog),
@@ -963,23 +933,29 @@ toggle_interface (ModemApplet *applet, gboolean enable)
 }
 
 static void
-on_modem_applet_activate (GtkAction   *action,
-			  ModemApplet *applet)
+on_modem_applet_activate (GSimpleAction *action,
+                          GVariant      *parameter,
+                          gpointer       user_data)
 {
+  ModemApplet *applet = (ModemApplet *) user_data;
   toggle_interface (applet, TRUE);
 }
 
 static void
-on_modem_applet_deactivate (GtkAction   *action,
-			    ModemApplet *applet)
+on_modem_applet_deactivate (GSimpleAction *action,
+                            GVariant      *parameter,
+                            gpointer       user_data)
 {
+  ModemApplet *applet = (ModemApplet *) user_data;
   toggle_interface (applet, FALSE);
 }
 
 static void
-on_modem_applet_properties_clicked (GtkAction   *action,
-				    ModemApplet *applet)
+on_modem_applet_properties_clicked (GSimpleAction *action,
+                                    GVariant      *parameter,
+                                    gpointer       user_data)
 {
+  ModemApplet *applet = (ModemApplet *) user_data;
   ModemAppletPrivate *priv = MODEM_APPLET_GET_PRIVATE (applet);
   GdkScreen *screen;
   GtkWidget *dialog;
@@ -1002,8 +978,9 @@ on_modem_applet_properties_clicked (GtkAction   *action,
 }
 
 static void
-on_modem_applet_about_clicked (GtkAction   *action,
-			       ModemApplet *applet)
+on_modem_applet_about_clicked (GSimpleAction *action,
+                               GVariant      *parameter,
+                               gpointer       user_data)
 {
   const gchar *authors[] = {
     "Carlos Garnacho Parro <carlosg@gnome.org>",
@@ -1025,16 +1002,6 @@ on_modem_applet_about_clicked (GtkAction   *action,
 			 NULL);
 }
 
-static void
-on_modem_applet_help_clicked (GtkAction   *action,
-			      ModemApplet *applet)
-{
-  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
-		"help:modemlights",
-		gtk_get_current_event_time (),
-		NULL);
-}
-
 static gboolean
 modem_applet_fill (ModemApplet *applet)
 {
@@ -1043,20 +1010,27 @@ modem_applet_fill (ModemApplet *applet)
 
   g_return_val_if_fail (PANEL_IS_APPLET (applet), FALSE);
 
+  panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
+
   gtk_widget_show_all (GTK_WIDGET (applet));
 
-  priv->action_group = gtk_action_group_new ("ModemLights Applet Actions");
-  gtk_action_group_set_translation_domain (priv->action_group, GETTEXT_PACKAGE);
-  gtk_action_group_add_actions (priv->action_group,
-				menu_actions,
-				G_N_ELEMENTS (menu_actions),
-				applet);
+  priv->action_group = g_simple_action_group_new ();
+  g_action_map_add_action_entries (G_ACTION_MAP (priv->action_group),
+                                   menu_actions, G_N_ELEMENTS (menu_actions),
+                                   applet);
   update_popup_buttons (applet);
   ui_path = g_build_filename (MODEM_MENU_UI_DIR, "modem-applet-menu.xml", NULL);
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-				     ui_path, priv->action_group);
+				     ui_path, priv->action_group,
+				     GETTEXT_PACKAGE);
   g_free (ui_path);
 
+  gtk_widget_insert_action_group (GTK_WIDGET (applet), "modem",
+                                  G_ACTION_GROUP (priv->action_group));
+
+  g_signal_connect (GTK_WIDGET (applet), "size-allocate",
+                    G_CALLBACK (modem_applet_size_allocate), applet);
+
   return TRUE;
 }
 
