@@ -210,10 +210,6 @@ trash_applet_init (TrashApplet *applet)
   /* needed to clamp ourselves to the panel size */
   panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
 
-  /* enable transparency hack */
-  panel_applet_set_background_widget (PANEL_APPLET (applet),
-                                      GTK_WIDGET (applet));
-
   /* setup the image */
   applet->image = g_object_ref_sink (gtk_image_new ());
   gtk_container_add (GTK_CONTAINER (applet),
